Data Coordination Platform Diagnostic Library and Tools
=======================================================

This repository and Python package contains diagnostic tools and a
library of code useful in building them.

## Installation

    pip install dcp-diag

